<?php
/**
 * @package    CAdvancedSlideshow
 * @author     Yves Hoppe <yves@compojoom.com>
 * @date       20.09.13
 *
 * @copyright  Copyright (C) 2008 - 2013 compojoom.com . All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 */

defined('_JEXEC') or die('Restricted access');

/**
 * Script file of com_cmc component
 *
 * @since  1.0
 */
class Com_CAdvancedSlideshowInstallerScript
{
	/*
	  * The release value to be displayed and checked against throughout this file.
	  */
	public $release = '3.0';

	public $minimum_joomla_release = '2.5.10';

	public $extension = 'com_cadvancedslideshow';

	/**
	 * @var CompojoomInstaller
	 */
	private $installer;

	private $status;

	private $installationQueue = array(
		// Modules => { (folder) => { (module) => { (position), (published) } }* }*
		'modules' => array(
			'admin' => array(),
			'site' => array(
				'mod_cadvancedslideshow' => array('banner', 0)
			)
		),
		// Key is the name without the lib_ prefix, value if the library should be autopublished
		'libraries' => array(
			'compojoom' => 1
		)
	);

	/**
	 * Executed on install/update/discover
	 *
	 * @param   string                      $type    - the type of th einstallation
	 * @param   JInstallerAdapterComponent  $parent  - the parent JInstaller obeject
	 *
	 * @return boolean - true if everything is OK and we should continue with the installation
	 */
	public function preflight($type, $parent)
	{
		$path = $parent->getParent()->getPath('source') . '/libraries/compojoom/libraries/compojoom/include.php';

		require_once $path;

		$this->installer = new CompojoomInstaller($type, $parent, 'com_cadvancedslideshow');

		if (!$this->installer->allowedInstall())
		{
			return false;
		}

		return true;
	}

	/**
	 * Method to uninstall the component
	 *
	 * @param   object  $parent  - the parent object
	 *
	 * @return void
	 */
	public function uninstall($parent)
	{
		require_once JPATH_LIBRARIES . '/compojoom/include.php';

		$this->installer = new CompojoomInstaller('uninstall', $parent, 'com_cadvancedslideshow');

		$this->status = new stdClass;

		// Let us install the modules & plugins
		$plugins = $this->installer->uninstallPlugins($this->installationQueue['plugins']);
		$modules = $this->installer->uninstallModules($this->installationQueue['modules']);

		$this->status->plugins = $plugins;
		$this->status->modules = $modules;

		echo $this->displayInfoUninstallation();
	}

	/**
	 * method to run after an install/update/discover method
	 *
	 * @param   string  $type    - the type
	 * @param   object  $parent  - the parent object
	 *
	 * @return void
	 */
	public function postflight($type, $parent)
	{
		$path = $parent->getParent()->getPath('source');
		$this->status = new stdClass;

		$dbInstaller = new CompojoomDatabaseInstaller(
			array(
				'dbinstaller_directory' => $path . '/administrator/components/com_cadvancedslideshow/sql/xml'
			)
		);
		$dbInstaller->updateSchema();

		// Let us install the modules
		$this->status->modules = $this->installer->installModules($this->installationQueue['modules']);
		$this->status->libraries = $this->installer->installLibraries($this->installationQueue['libraries']);

		$this->status->cb = false;

		// Copy images
		JFolder::create(JPATH_ROOT . "/images/cadvancedslideshow/sample");
		$src = $parent->getParent()->getPath('source');

		JFile::copy($src . "/images/cadvancedslideshow/sample/slide1-0428.jpg", JPATH_ROOT . "/images/cadvancedslideshow/sample/slide1-0428.jpg");
		JFile::copy($src . "/images/cadvancedslideshow/sample/slide2-0445.jpg", JPATH_ROOT . "/images/cadvancedslideshow/sample/slide2-0445.jpg");
		JFile::copy($src . "/images/cadvancedslideshow/sample/slide3-0471.jpg", JPATH_ROOT . "/images/cadvancedslideshow/sample/slide3-0471.jpg");
		JFile::copy($src . "/images/cadvancedslideshow/sample/slide4-0135.jpg", JPATH_ROOT . "/images/cadvancedslideshow/sample/slide4-0135.jpg");
		JFile::copy($src . "/images/cadvancedslideshow/sample/slide5-0167.jpg", JPATH_ROOT . "/images/cadvancedslideshow/sample/slide5-0167.jpg");

		echo $this->displayInfoInstallation();
	}

	/**
	 * Display installation info
	 *
	 * @return string
	 */
	private function displayInfoInstallation()
	{
		$html[] = '<div class="alert alert-info">' . JText::_('COM_CADAVANCEDSLIDESHOW_INSTALLATION_SUCCESS') . '</div>';

		$html[] = CompojoomHtmlTemplates::renderSocialMediaInfo();


		if ($this->status->libraries)
		{
			$html[] = $this->installer->renderLibraryInfoInstall($this->status->libraries);
		}

		if ($this->status->modules)
		{
			$html[] = $this->installer->renderModuleInfoInstall($this->status->modules);
		}

		return implode('', $html);
	}

	/**
	 * Displays uninstall info
	 *
	 * @return string
	 */
	public function displayInfoUninstallation()
	{
		$html[] = $this->installer->renderModuleInfoUninstall($this->status->modules);

		$html[] = CompojoomHtmlTemplates::renderSocialMediaInfo();

		return implode('', $html);
	}
}